caellion-python-commons: caellion.pycommons.stringutil Namespace Reference

caellion-python-commons

Namespaces
caellion.pycommons.stringutil Namespace Reference

This package provides facilities related to formatting strings. More...

## Namespaces
| formatters
| This module provides various string formatters.
| unixpassword
| This module provides utlilities related to creating, reading, writing and parsing of linux-style passwd/shadow file.

## Detailed Description

This package provides facilities related to formatting strings.